@@ -109,6 +109,61 @@ void XML::removeProgram(QString name)
     file.close();
 }
 
+void XML::removeHistory(QString name, QString date)
+{
+    qDebug() << "XML::removeHistory" << name << " " << date;
+    QDomDocument doc( "Exercises" );
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/history.xml" );
+    if( !file.open( QIODevice::ReadOnly ) )
+    {
+        return;
+    }
+    doc.setContent(&file);
+    file.close();
+    qDebug() << "XML::removeHistory 1";
+    QDomElement root = doc.documentElement();
+    if( root.tagName() != "exercise" )
+    {
+        return;
+    }
+    QDomNode n = root.firstChild();
+    while( !n.isNull() )
+    {
+      QDomElement e = n.toElement();
+      if( !e.isNull() )
+      {
+        if( e.tagName() == "exercise" )
+        {
+            if(e.attribute("name", "") == name && date == "0")
+            {
+                qDebug() << "XML::removeHistory 2";
+                date = e.attribute("date", "");
+            }
+
+            if(e.attribute("name", "") == name)
+            {
+                if( e.attribute("date", "") == date)
+                {
+                    qDebug() << "XML::removeHistory 3";
+                    root.removeChild(n);
+                }
+            }
+        }
+
+      }
+
+      n = n.nextSibling();
+   }
+
+    if( !file.open( QIODevice::WriteOnly ) )
+      return;
+    QTextStream ts( &file );
+    ts << doc.toString();
+
+    file.close();
+}
+
 void XML::saveProgram(QString name, QModelIndexList exercises)
 {
     QDomDocument doc( "Program" );
@@ -426,7 +481,7 @@ QList <QString> XML::getHistoryByExercise(QString name, QString date)
 {
     QList <QString> readInfo;
     QString j;
-
+    qDebug() << "XML::getHistoryByExercise" << name << " " << date;
     QDomDocument doc( "Exercises" );
     QString str = "/home/user/.qexercise";
     QFile file( str + "/history.xml" );
@@ -436,7 +491,7 @@ QList <QString> XML::getHistoryByExercise(QString name, QString date)
     }
     doc.setContent(&file);
     file.close();
-
+    qDebug() << "XML::getHistoryByExercise 1";
     QDomElement root = doc.documentElement();
     if( root.tagName() != "exercise" )
     {
@@ -452,17 +507,22 @@ QList <QString> XML::getHistoryByExercise(QString name, QString date)
         {
             if(e.attribute("name", "") == name && date == "0")
             {
+                qDebug() << "XML::getHistoryByExercise 2";
                 date = e.attribute("date", "");
             }
 
-            if(e.attribute("name", "") == name && e.attribute("date", "") == date)
+            if(e.attribute("name", "") == name)
             {
-                for(int i = 1; i < 10; i++)
+                if( e.attribute("date", "") == date)
                 {
-                    j.setNum(i);
-                    readInfo.append(e.attribute("variable" + j, ""));
-                    readInfo.append(e.attribute("reps" + j, ""));
-                    readInfo.append(e.attribute("status" + j, ""));
+                    qDebug() << "XML::getHistoryByExercise 3";
+                    for(int i = 1; i < 10; i++)
+                    {
+                        j.setNum(i);
+                        readInfo.append(e.attribute("variable" + j, ""));
+                        readInfo.append(e.attribute("reps" + j, ""));
+                        readInfo.append(e.attribute("status" + j, ""));
+                    }
                 }
             }
         }
